@@ -2,7 +2,7 @@
 #
 # Author: Mike McKerns (mmckerns @caltech and @uqfoundation)
 # Copyright (c) 2015-2016 California Institute of Technology.
-# Copyright (c) 2016-2018 The Uncertainty Quantification Foundation.
+# Copyright (c) 2016-2019 The Uncertainty Quantification Foundation.
 # License: 3-clause BSD.  The full license text is available at:
 #  - https://github.com/uqfoundation/pathos/blob/master/LICENSE
 
@@ -21,7 +21,7 @@ y = range(5)
 
 
 if __name__ == '__main__':
-    from pathos.helpers import freeze_support
+    from pathos.helpers import freeze_support, shutdown
     freeze_support()
 
     from pathos.pools import ProcessPool, ThreadPool
@@ -39,4 +39,6 @@ if __name__ == '__main__':
 
     print(amap(tmap, [sin,cos], [x,x]).get())
 
+    shutdown()
 
+# EOF
