@@ -2,7 +2,7 @@
 #
 # Author: Mike McKerns (mmckerns @caltech and @uqfoundation)
 # Copyright (c) 1997-2016 California Institute of Technology.
-# Copyright (c) 2016-2018 The Uncertainty Quantification Foundation.
+# Copyright (c) 2016-2019 The Uncertainty Quantification Foundation.
 # License: 3-clause BSD.  The full license text is available at:
 #  - https://github.com/uqfoundation/pathos/blob/master/LICENSE
 
@@ -20,8 +20,8 @@ add_me = adder(5)
 squ = lambda x:x**2
 
 
-if __name__ is '__main__':
-    from pathos.helpers import freeze_support
+if __name__ == '__main__':
+    from pathos.helpers import freeze_support, shutdown
     freeze_support()
 
     from pathos.pools import ProcessPool as Pool
@@ -50,4 +50,7 @@ if __name__ is '__main__':
     print(tpool.map(squ, range(10)))
     print('')
 
+    # shutdown all cached pools
+    shutdown()
+
 # end of file
