@@ -7,7 +7,7 @@
 # Forked by: Mike McKerns (April 2008)
 # Author: Mike McKerns (mmckerns @caltech and @uqfoundation)
 # Copyright (c) 2008-2016 California Institute of Technology.
-# Copyright (c) 2016-2018 The Uncertainty Quantification Foundation.
+# Copyright (c) 2016-2019 The Uncertainty Quantification Foundation.
 # License: 3-clause BSD.  The full license text is available at:
 #  - https://github.com/uqfoundation/pathos/blob/master/LICENSE
 #
@@ -186,7 +186,7 @@ NOTE: if a tuple of servers is not provided, defaults to localhost only
         #_pool.set_ncpus(ncpus or 'autodetect') # no ncpus=0
        #print("configure %s local workers" % _pool.get_ncpus())
         return
-    __init__.__doc__ = AbstractWorkerPool.__init__.__doc__ + __init__.__doc__
+    if AbstractWorkerPool.__init__.__doc__: __init__.__doc__ = AbstractWorkerPool.__init__.__doc__ + __init__.__doc__
    #def __exit__(self, *args):
    #    self._clear()
    #    return
@@ -266,7 +266,7 @@ NOTE: if a tuple of servers is not provided, defaults to localhost only
                         break
                 # yield it.pop(0).get()  # wait for the first element?
                 # *subprocess*           # alternately, loop in a subprocess
-            raise StopIteration
+            return #raise StopIteration
         # submit all jobs, then collect results as they become available
         return imap_unordered(builtins.map(submit, *args))
     uimap.__doc__ = AbstractWorkerPool.uimap.__doc__
@@ -420,6 +420,7 @@ NOTE: if a tuple of servers is not provided, defaults to localhost only
     ncpus = property(__get_nodes, __set_nodes)
     nodes = property(__get_nodes, __set_nodes)
     servers = property(__get_servers, __set_servers)
+    __state__ = __STATE
     pass
 
 
